@@ -1,5 +1,38 @@
 //Materialテーマ相互運用機能
 
+//印刷用ページの設定
+function isPrintMode(){
+    var i = new URL(window.location.href);
+    var pms = i.searchParams;
+    return pms.has('embed');
+}
+
+function togglePrintMode(){
+if(isPrintMode()) {
+    document.querySelectorAll('.print-hide').forEach(element =>element.parentNode.removeChild(element));
+    document.querySelectorAll('.print-visible').forEach(element =>element.classList.remove('d-none'));
+    document.querySelector('.print-main').classList.remove('col-md-8');
+}}
+
+togglePrintMode();
+
+function print_view(){
+    var url = new URL(window.location.href);
+	url.searchParams.append('embed','');
+	location.href = url;
+}
+
+function print_normal(){
+    var url = new URL(window.location.href);
+	url.searchParams.delete('embed');
+	window.open(url);
+}
+
+function share_to_facebook(){
+    alert('http://www.facebook.com/share.php?u='+escape(location.href));
+    location.href='http://www.facebook.com/share.php?u='+escape(location.href);
+}
+
 //該当するクラスを置換するメソッド
 function replace_class(base,to){
     document.querySelectorAll('.'+base).forEach(element => element.classList.replace(base,to));
@@ -11,7 +44,8 @@ function add_class(base,to){
 //MaterialのAdmonitionをAlertに置換
 replace_class('admonition','alert');
 replace_class('admonition-title','alert-heading');
-$(".alert-heading a").addClass("alert-link");
+$(".alert a").addClass("alert-link");
+$(".alert a").addClass("text-decoration-underline");
 
 //MaterialのAdmonition色をAlert色に置換
 add_class('note','alert-primary');
@@ -45,6 +79,18 @@ function copy_btn_clicked(btn){
     btn.querySelector('.'+ICON_COPY).classList.replace(ICON_COPY,ICON_COPY_CHECK);
 }
 
+//ページのコピーボタンが押されたときの処理
+function page_copy_btn_clicked(btn){
+    $(document.body).append("<textarea id=\"copyTarget\" style=\"position:absolute; left:-9999px; top:0px;\" readonly=\"readonly\">" +location.href+ "</textarea>");
+  let obj = document.getElementById("copyTarget");
+  let range = document.createRange();
+  range.selectNode(obj);
+  window.getSelection().addRange(range);
+  document.execCommand('copy');
+    btn.querySelector('.'+ICON_COPY).classList.add('text-success');
+    btn.querySelector('.'+ICON_COPY).classList.replace(ICON_COPY,ICON_COPY_CHECK);
+}
+
 //表をBootstrap仕様に
 $("table").addClass("table");
 
@@ -84,6 +130,21 @@ function toggle_toc(toc){
     }
 }
 
+function search(ismobile){
+    let query=document.getElementById('searchbox').value;
+    if(ismobile){
+        query=document.getElementById('searchbox_mobile').value;
+    }
+    let target = document.getElementById('mkdocs-search-query');
+    target.value=query;
+    let e = new Event('keyup');
+    target.dispatchEvent(e);
+    let searchModal = new bootstrap.Modal(document.getElementById('searchModal'), {
+        keyboard: false
+      });
+    searchModal.show();
+}
+
 let url = new URL(window.location.href);
 let params = url.searchParams;
 
@@ -94,4 +155,4 @@ document.getElementById('searchbox_mobile').value=get_query;
 
 $('.nav_cop').click(function() {
     $(this).next().collapse('toggle');
-});
\ No newline at end of file
+});
